from django.shortcuts import render
from django.conf import settings as django_settings
from django_simple_third_party_jwt import settings
from django_simple_third_party_jwt_dev_dashboard.forms import UserForm
from django_simple_third_party_jwt_dev_dashboard.settings import DEV_DASHBOARD_SETTINGS

import logging

logger = logging.getLogger(__name__)

jwt_refresh_url = DEV_DASHBOARD_SETTINGS.get('jwt_refresh_url', '')
jwt_verify_url = DEV_DASHBOARD_SETTINGS.get('jwt_verify_url', '')
jwt_token_url = DEV_DASHBOARD_SETTINGS.get('jwt_token_url', '')
dashboard_url = DEV_DASHBOARD_SETTINGS.get('dashboard_url', '')
third_party_jwt_url = DEV_DASHBOARD_SETTINGS.get('third_party_jwt_url', '')
admin_url = DEV_DASHBOARD_SETTINGS.get('admin_url', '')
swagger_url = DEV_DASHBOARD_SETTINGS.get('swagger_url', '')
redoc_url = DEV_DASHBOARD_SETTINGS.get('redoc_url', '')

debug = django_settings.DEBUG

dev_dashboard_setting = {
    'social_google_client_id': settings.SOCIAL_GOOGLE_CLIENT_ID,
    'jwt_token_url': jwt_token_url,
    'jwt_refresh_url': jwt_refresh_url,
    'jwt_verify_url': jwt_verify_url,
    'dashboard_url': dashboard_url,
    'third_party_jwt_url': third_party_jwt_url,
    'admin_url': admin_url,
    'swagger_url': swagger_url,
    'redoc_url': redoc_url,
    'debug': debug,
}


def dashboard(request):
    return render(
        request,
        "dashboard/dashboard.html",
        dev_dashboard_setting
    )

def jwt_login(request):
    dev_dashboard_setting_ = dev_dashboard_setting.copy()
    dev_dashboard_setting_['form'] = UserForm
    return render(
        request,
        "login.html",
        dev_dashboard_setting_
    )





from django.conf import settings

DEV_DASHBOARD_SETTINGS = getattr(settings, "DEV_DASHBOARD_SETTINGS", {
    'jwt_token_url': 'api/auth/token',
    'jwt_refresh_url': 'api/auth/token/refresh',
    'jwt_verify_url': 'api/auth/token/verify',
    'dashboard_url': 'api/__hidden_dev_dashboard',
    'third_party_jwt_url': 'api/auth/google',
    'admin_url': 'api/__hidden_admin',
    'swagger_url': 'api/__hidden_swagger',
    'redoc_url': 'api/__hidden_redoc',
})



import setuptools

with open('README.md', 'r', encoding='utf-8') as fh:
    long_description = fh.read()

PROJECT_NAME = 'django-simple-third-party-jwt-dev-dashboard'
GIT_REPO_NAME = 'Django-Simple-3rd-Party-JWT-Dev-Dashboard'

setuptools.setup(
    name=PROJECT_NAME,
    fullname=PROJECT_NAME,
    author='Nat Lee',
    author_email='natlee.work@gmail.com',
    description='Dashboard for using JWT with 3rd party login.',
    keywords='django, jwt, 3rd party login, dashboard, toolbox',
    long_description=long_description,
    long_description_content_type='text/markdown',
    url=f'https://github.com/NatLee/{GIT_REPO_NAME}',
    project_urls={
        'Documentation': f'https://github.com/natlee/{GIT_REPO_NAME}',
        'Bug Reports': f'https://github.com/natlee/{GIT_REPO_NAME}/issues',
        'Source Code': f'https://github.com/natlee/{GIT_REPO_NAME}',
        # 'Funding': '',
        # 'Say Thanks!': '',
    },
    package_dir={'': 'src'},
    packages=setuptools.find_packages(where='src'),
    package_data={
        "django_simple_third_party_jwt_dev_dashboard": [
            "templates/*",
            "templates/dashboard/*",
            "templates/registration/*",
        ]
    },
    classifiers=[
        # see https://pypi.org/classifiers/
        'Development Status :: 5 - Production/Stable',

        'Intended Audience :: Developers',
        'Topic :: Software Development :: Build Tools',

        'Programming Language :: Python :: 3',
        'Programming Language :: Python :: 3.8',
        'Programming Language :: Python :: 3.9',
        'Programming Language :: Python :: 3 :: Only',
        'License :: OSI Approved :: MIT License',
        'Operating System :: OS Independent',
    ],
    python_requires='>=3.8',
    install_requires=[
        'django>=4.0.0',
        'djangorestframework',
        'django-simple-third-party-jwt',
        'drf-yasg',
        'django-bootstrap3'
    ],
    extras_require={
        'dev': ['check-manifest'],
        # 'test': ['coverage'],
    },
)
